pub struct StudentForm {Show 40 fields
pub family_name: String,
pub first_name: String,
pub email: String,
pub second_name: Option<String>,
pub preferred_name: Option<String>,
pub gender: Option<String>,
pub birth_date: Option<NaiveDateTime>,
pub enrol_year: String,
pub start_date: Option<NaiveDateTime>,
pub enroled_siblings: bool,
pub siblings: Option<Vec<Sibling>>,
pub aboriginality: Option<AboriginalityType>,
pub lang_other_eng: bool,
pub other_main_lang: Option<String>,
pub other_langs: Option<String>,
pub phone_number: Option<String>,
pub residency_status: ResidencyType,
pub date_of_arrival: Option<NaiveDateTime>,
pub return_date: Option<NaiveDateTime>,
pub visa_subclass: Option<i32>,
pub visa_expiry_date: Option<NaiveDateTime>,
pub first_enrolment_date: Option<NaiveDateTime>,
pub previous_schools: Option<Vec<PreviousSchool>>,
pub in_non_parental_care: bool,
pub preschool_education: Option<bool>,
pub preschool_time: Option<String>,
pub preschool_postcode: Option<i32>,
pub long_day_care_with: Option<bool>,
pub long_day_care_with_time: Option<String>,
pub long_day_care_with_postcode: Option<i32>,
pub long_day_care_without: Option<bool>,
pub long_day_care_without_time: Option<String>,
pub long_day_care_without_postcode: Option<i32>,
pub family_day_care: Option<bool>,
pub family_day_care_time: Option<String>,
pub grandparent: Option<bool>,
pub grandparent_time: Option<String>,
pub other_care: Option<bool>,
pub other_care_time: Option<String>,
pub name_care_service: Option<String>,
}Fields
family_name: Stringfirst_name: Stringemail: Stringsecond_name: Option<String>preferred_name: Option<String>gender: Option<String>birth_date: Option<NaiveDateTime>enrol_year: Stringstart_date: Option<NaiveDateTime>enroled_siblings: boolsiblings: Option<Vec<Sibling>>aboriginality: Option<AboriginalityType>lang_other_eng: boolother_main_lang: Option<String>other_langs: Option<String>phone_number: Option<String>residency_status: ResidencyTypedate_of_arrival: Option<NaiveDateTime>return_date: Option<NaiveDateTime>visa_subclass: Option<i32>visa_expiry_date: Option<NaiveDateTime>first_enrolment_date: Option<NaiveDateTime>previous_schools: Option<Vec<PreviousSchool>>in_non_parental_care: boolpreschool_education: Option<bool>preschool_time: Option<String>preschool_postcode: Option<i32>long_day_care_with: Option<bool>long_day_care_with_time: Option<String>long_day_care_with_postcode: Option<i32>long_day_care_without: Option<bool>long_day_care_without_time: Option<String>long_day_care_without_postcode: Option<i32>family_day_care: Option<bool>family_day_care_time: Option<String>grandparent: Option<bool>grandparent_time: Option<String>other_care: Option<bool>other_care_time: Option<String>name_care_service: Option<String>Trait Implementations
Sourceimpl Clone for StudentForm
impl Clone for StudentForm
Sourcefn clone(&self) -> StudentForm
fn clone(&self) -> StudentForm
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StudentForm
impl Debug for StudentForm
Sourceimpl Default for StudentForm
impl Default for StudentForm
Sourcefn default() -> StudentForm
fn default() -> StudentForm
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StudentForm
impl<'de> Deserialize<'de> for StudentForm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> FromSql<'a> for StudentForm
impl<'a> FromSql<'a> for StudentForm
Sourcefn from_sql(
_type: &Type,
buf: &'a [u8],
) -> Result<StudentForm, Box<dyn Error + Sync + Send>>
fn from_sql( _type: &Type, buf: &'a [u8], ) -> Result<StudentForm, Box<dyn Error + Sync + Send>>
Creates a new value of this type from a buffer of data of the specified
Postgres
Type in its binary format. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be created from the specified
Postgres
Type.Sourceimpl Serialize for StudentForm
impl Serialize for StudentForm
Sourceimpl ToSql for StudentForm
impl ToSql for StudentForm
Sourcefn to_sql(
&self,
_type: &Type,
buf: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql( &self, _type: &Type, buf: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
Converts the value of
self into the binary format of the specified
Postgres Type, appending it to out. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be converted to the specified
Postgres
Type.Sourcefn to_sql_checked(
&self,
ty: &Type,
out: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql_checked( &self, ty: &Type, out: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
An adaptor method used internally by Rust-Postgres. Read more
Sourcefn encode_format(&self, _ty: &Type) -> Format
fn encode_format(&self, _ty: &Type) -> Format
Specify the encode format